@@ -1,5 +1,6 @@
 /***************************************************************************
-* Copyright (c) 2016, Johan Mabille, Sylvain Corlay and Wolf Vollprecht    *
+* Copyright (c) Johan Mabille, Sylvain Corlay and Wolf Vollprecht          *
+* Copyright (c) QuantStack                                                 *
 *                                                                          *
 * Distributed under the terms of the BSD 3-Clause License.                 *
 *                                                                          *
@@ -17,6 +18,32 @@
 
 namespace xt
 {
+    namespace detail
+    {
+        template <class D>
+        struct is_sharable
+        {
+            static constexpr bool value = true;
+        };
+
+        template <class ET, class S, layout_type L, bool SH, class Tag>
+        struct is_sharable<xfixed_container<ET, S, L, SH, Tag>>
+        {
+            static constexpr bool value = SH;
+        };
+
+        template <class ET, class S, layout_type L, bool SH, class Tag>
+        struct is_sharable<xfixed_adaptor<ET, S, L, SH, Tag>>
+        {
+            static constexpr bool value = SH;
+        };
+    }
+
+    template <class D>
+    using select_expression_base_t = std::conditional_t<detail::is_sharable<D>::value,
+                                                        xsharable_expression<D>,
+                                                        xexpression<D>>;
+
     /**
      * @class xsemantic_base
      * @brief Base interface for assignable xexpressions.
@@ -28,11 +55,11 @@ namespace xt
      *           provides the interface.
      */
     template <class D>
-    class xsemantic_base : public xexpression<D>
+    class xsemantic_base : public select_expression_base_t<D>
     {
     public:
 
-        using base_type = xexpression<D>;
+        using base_type = select_expression_base_t<D>;
         using derived_type = typename base_type::derived_type;
 
         using temporary_type = typename xcontainer_inner_types<D>::temporary_type;
@@ -127,6 +154,15 @@ namespace xt
         derived_type& operator=(const xexpression<E>&);
     };
 
+    template <class E>
+    using is_assignable = is_crtp_base_of<xsemantic_base, E>;
+
+    template <class E, class R = void>
+    using enable_assignable = typename std::enable_if<is_assignable<E>::value, R>::type;
+
+    template <class E, class R = void>
+    using disable_assignable = typename std::enable_if<!is_assignable<E>::value, R>::type;
+
     /**
      * @class xcontainer_semantic
      * @brief Implementation of the xsemantic_base interface
@@ -641,7 +677,7 @@ namespace xt
             using index_type = xindex_type_t<typename xfunction<F, R, CT...>::shape_type>;
             using size_type = typename index_type::size_type;
             size_type size = rhs.dimension();
-            index_type shape = xtl::make_sequence<index_type>(size, size_type(0));
+            index_type shape = uninitialized_shape<index_type>(size);
             bool trivial_broadcast = rhs.broadcast_shape(shape, true);
             return trivial_broadcast;
         }
@@ -665,6 +701,21 @@ namespace xt
         return this->derived_cast();
     }
 
+    namespace xview_semantic_detail
+    {
+        template <class D>
+        auto get_begin(D&& lhs, std::true_type)
+        {
+            return lhs.storage_begin();
+        }
+
+        template <class D>
+        auto get_begin(D&& lhs, std::false_type)
+        {
+            return lhs.begin();
+        }
+    }
+
     template <class D>
     template <class E, class F>
     inline auto xview_semantic<D>::scalar_computed_assign(const E& e, F&& f) -> derived_type&
@@ -672,7 +723,7 @@ namespace xt
         D& d = this->derived_cast();
 
         using size_type = typename D::size_type;
-        auto dst = d.begin();
+        auto dst = xview_semantic_detail::get_begin(d, std::integral_constant<bool, D::contiguous_layout>());
         for (size_type i = d.size(); i > 0; --i)
         {
             *dst = f(*dst, e);
